@@ -2142,8 +2142,6 @@ main (int argc, char *argv[])
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	if (! g_thread_supported ())
-		g_thread_init (NULL);
 	g_type_init ();
 
 	gtk_init (&argc, &argv);
